@@ -2,8 +2,10 @@ import os
 import sys
 import time
 import configparser
+import subprocess
 from pathlib import Path
 from atp.server_run import ServerRun
+from atp.common_read_write import write_data, read_data
 
 
 def workspace(sys_name, data):
@@ -26,14 +28,16 @@ def workspace(sys_name, data):
     work_space = cwd_dir / ('x_atp_server_%s' % data_dict['name'])
     os.mkdir(str(work_space))
     create_profile(data=data_dict, work_space=work_space, current_dir=current_dir)
-    print('\n###   工作空间   ###\nx_atp_server_%s\n' % data_dict['name'])
-    # 后台执行atp执行端
+    print('\n###执行端目录 x_atp_server_%s 已创建完成 ### ' % data_dict['name'])
+    # 启动执行端
     if sys_name == 'Linux':
-        daemon_start(data=data_dict, work_space=work_space)
-        print('###   X-ATP自动化测试执行端服务已在后台运行   ###')
+        cmd = 'x-atp-cli -s ' + str(work_space)
+        popen = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE)
+        # 等待shell执行执行完成，此处不等待的话，父程序会直接结束，导致 x-atp-cli -s 的指令PPID变为1，会被kill掉
+        popen.wait(timeout=10)
+        print("### 执行机 %s 已运行 ### " % data_dict['name'])
     else:
-        print('###   您需要手动启动执行端服务   ###\ncd x_atp_server_%s\npython server_run.py\n'
-              % data_dict['name'])
+        print("### 您需要手动启动执行端服务 ###python %s/server_run.py\n" % work_space)
 
 
 def create_profile(data, work_space, current_dir):
@@ -59,14 +63,19 @@ def create_profile(data, work_space, current_dir):
     # 保存config配置文件
     with open(work_space / file, 'w', encoding='utf-8') as configfile:
         config.write(configfile)
+    copy_file(current_dir=current_dir, work_space=work_space)
+
+
+def copy_file(current_dir, work_space):
     # 拷贝server_run执行文件到工作空间
-    with open(work_space / 'server_run.py', 'w', encoding='utf-8') as file_obj:
-        with open(current_dir / 'server_run.py', 'r', encoding='utf-8') as api_run:
-            file_obj.write(api_run.read())
+    file_obj = read_data(current_dir / 'server_run.py', '', 'r')
+    write_data(work_space / 'server_run.py', file_obj, 'w+', 'w+')
     # 拷贝自动化测试框架执行文件到工作空间
-    with open(work_space / 'exec_testcase.py', 'w', encoding='utf-8') as file_exec:
-        with open(current_dir / 'exec_testcase.py', 'r', encoding='utf-8') as exec_demo:
-            file_exec.write(exec_demo.read())
+    file_exec = read_data(current_dir / 'exec_testcase.py', '', 'r')
+    write_data(work_space / 'exec_testcase.py', file_exec, 'w+', 'w+')
+    # 拷贝默认report报告到工作空间
+    file_report = read_data(current_dir / 'def_report.xlsx', '', 'rb')
+    write_data(work_space / 'def_report.xlsx', file_report, 'wb', 'w+')
 
 
 def daemon_start(data, work_space, stdin='/dev/null', stdout='/dev/null', stderr='/var/log/x-atp-api-server.error'):
@@ -94,7 +103,7 @@ def daemon_start(data, work_space, stdin='/dev/null', stdout='/dev/null', stderr
     # 父进程退出后，子进程由init收养
     # setsid使子进程成为新的会话首进程和进程组的组长，与原来的进程组、控制终端和登录会话脱离
     os.setsid()
-    # 防止在类似于临时挂载的文件系统下运行，例如/mnt文件夹下，这样守护进程一旦运行，临时挂载的文件系统就无法卸载了，这里我们推荐把当前工作目录切换到根目录下
+    # 防止在类似于临时挂载的文件系统下运行，例如/mnt文件夹下，这样守护进程一旦运行，临时挂载的文件系统就无法卸载了，所以把目录设置到工作目录下
     os.chdir(work_space)
     # 设置用户创建文件的默认权限，设置的是权限“补码”，这里将文件权限掩码设为0，使得用户创建的文件具有最大的权限。否则，默认权限是从父进程继承得来的
     os.umask(0)
@@ -108,5 +117,5 @@ def daemon_start(data, work_space, stdin='/dev/null', stdout='/dev/null', stderr
         sys.stderr.write("[Api Server Error]> 第二次 fork 失败, " + e.strerror)
         os._exit(1)
     # 此时改程序已经是守护进程了，再执行需要后台执行的程序即可
-    r = ApiRun(data)
+    r = ServerRun(data)
     r.run()
