@@ -6,8 +6,8 @@ import json
 import platform
 import configparser
 import requests
-import datetime
 import redis
+import subprocess
 from git import Repo
 from atp.common_read_write import write_data, read_data
 
@@ -53,13 +53,13 @@ class ServerRun:
         os.mkdir(src_path)
 
     @staticmethod
-    def reset_file_tree(file_name, project_name, test_environment):
+    def reset_file_tree(file_name, project_name, test_type, test_environment):
         """
         将Git用例仓库里的project_name项目目录中的file_name文件复制到执行目录中
         """
         case_path = os.path.join(os.getcwd(), "git_case")
         lib_dst_path = os.path.join(
-            case_path, project_name + "-Project-api", test_environment, file_name)
+            case_path, project_name + "-Project-" + test_type, test_environment, file_name)
         # 确定Git用例存储库中是否有一个lib_dst_path目录
         if os.path.isdir(lib_dst_path):
             lib_src_path = os.path.join(os.getcwd(), file_name)
@@ -88,38 +88,26 @@ class ServerRun:
         """
         复制指定测试项目、测试类型、测试环境中的相关目录到自动化运行目录下
         """
-        self.reset_file_tree(file_name="lib", project_name=test_project, test_environment=test_environment)
-        self.reset_file_tree(file_name="data", project_name=test_project, test_environment=test_environment)
-        self.reset_file_tree(file_name="element", project_name=test_project, test_environment=test_environment)
-        self.reset_file_tree(file_name="testcase", project_name=test_project, test_environment=test_environment)
-        self.reset_file_tree(file_name="files", project_name=test_project, test_environment=test_environment)
+        ServerRun.reset_file_tree(file_name="lib", project_name=test_project, test_type=self.TEST_TYPE,
+                                  test_environment=test_environment)
+        ServerRun.reset_file_tree(file_name="data", project_name=test_project, test_type=self.TEST_TYPE,
+                                  test_environment=test_environment)
+        ServerRun.reset_file_tree(file_name="element", project_name=test_project, test_type=self.TEST_TYPE,
+                                  test_environment=test_environment)
+        ServerRun.reset_file_tree(file_name="testcase", project_name=test_project, test_type=self.TEST_TYPE,
+                                  test_environment=test_environment)
+        ServerRun.reset_file_tree(file_name="files", project_name=test_project, test_type=self.TEST_TYPE,
+                                  test_environment=test_environment)
         ServerRun.mkdir_and_del(src_path=os.path.join(os.getcwd(), "JUnit"))
         ServerRun.mkdir_and_del(src_path=os.path.join(os.getcwd(), "report"))
         ServerRun.mkdir_and_del(src_path=os.path.join(os.getcwd(), "details"))
 
-    def read_log_file(self):
+    @staticmethod
+    def read_log_file(log_file_list):
         """
         从以日期为维度统计的日志中提取出本次的日志文件，保存至log/new.log
         """
-        # 如果日志文件的日期前缀不是当天的日期
-        if self.initial_log_time != time.strftime('%Y%m%d'):
-            # 重置日志文件的前缀、起始行数
-            self.initial_log_time = time.strftime('%Y%m%d')
-            self.initial_log_line = 0
-        # 读取日志文件的全部字符串
-        with open(os.path.join(os.getcwd(), 'log', time.strftime('%Y%m%d.log')), "r", encoding='utf-8') as f:
-            # 将日志字符串按换行符拆成列表
-            log_file_data = f.read().split('\n')
-        # 如果起始日志行反而比最大行数都大的话
-        if self.initial_log_line > len(log_file_data):
-            # 重置日志文件的起始行数
-            self.initial_log_line = 0
-        # 按行号增量取出本次测试的日志
-        log_file_list = log_file_data[self.initial_log_line:]
-        # 更新日志文件的起始行号
-        self.initial_log_line = len(log_file_data)
-        # 存储日志信息的字典
-        log_file_dict = {}
+        log_file_dict = {"0": "None"}
         # 用这个变量控制每一行都是不重复的
         previous_row = ''
         # 整理每一行日志
@@ -148,31 +136,36 @@ class ServerRun:
             # 更新上一行的数据
             previous_row = log_file_list[i]
         # 在log目录下写入新的日志文件
-        with open(os.path.join('log', 'new.log'), "w", encoding='utf-8') as file:
-            file.write(json.dumps(log_file_dict))
+        write_data(os.path.join("log", "new.log"), log_file_dict, 'json', 'w+')
 
-    @staticmethod
-    def write_test_data_and_run(test_name, test_type):
+    def write_test_data_and_run(self, test_name, test_type):
         """写入测试所需数据并执行测试"""
         run_case_data = {'test_name': test_name, 'test_type': test_type, 'status': False}
         write_data('./run_case_data.json', run_case_data, 'json', 'w+')
         sys_name = platform.system()
         if sys_name == 'Linux':
             # 启动run_case模块
-            os.system('nohup python3 ./exec_testcase.py &')
+            popen = subprocess.Popen('nohup python3 ./exec_testcase.py &', shell=True, stdout=subprocess.PIPE,
+                                     stderr=subprocess.STDOUT)
         else:
-            os.popen('start python ./exec_testcase.py')
-        # 隐式等待/避免执行端假死
-        now_time_flag = datetime.datetime.now()
-        while True:
-            time.sleep(5)
-            if (datetime.datetime.now() - now_time_flag).seconds > 3600:
-                break
-            else:
-                status = read_data('./run_case_data.json', 'json', 'r')
-                # 如果运行结束状态status：True，继续下一步
-                if status['status']:
-                    return status.get('msg', '')
+            # 有的Windows系统中必须有环境变量python3,如果变量无配置python3的则无法启动
+            popen = subprocess.Popen('start python3 ./exec_testcase.py', shell=True)
+        # 存储超时的报错信息变量
+        timeout_msg = ''
+        # 隐式等待/避免执行端假死,linux环境下能用，Windows环境下无效
+        try:
+            popen.wait(timeout=3600)
+        except Exception as exc:
+            timeout_msg = exc
+            popen.kill()
+        # 获取标准输出内容
+        log_stdout = popen.stdout.read().decode()
+        # 将标准输出的每行转化为list的元素
+        log_stdout_list = log_stdout.split('\n')
+        # 将超时信息加入list元素中
+        log_stdout_list.append(str(timeout_msg))
+        # 调用日志处理函数，将日志输出到log/new.log
+        self.read_log_file(log_file_list=log_stdout_list)
 
     def post_heartbeat(self, status, localtime=None, task_dict=None, remark=None):
         """
@@ -210,28 +203,29 @@ class ServerRun:
                            'remark': remark}
                 # 状态为4时，组织待上传的次数报告文件
                 if status == 4:
-                    # 拔高变量的层级
-                    files_report = None
-                    files_junit = None
-                    # 取出XXX-Report@XXXXXX_XXX.xlsx的测试报告文件名
+                    # 设置默认日志内容，如果没有生成则上传默认文件内容
+                    files_report_obj = read_data(os.path.join('def_report.xlsx'), '', 'rb')
+                    files_junit_obj = b'None'
+                    files_details_obj = b'None'
+                    files_log_obj = b'None'
+                    # 如果文件存在则取出XXX-Report@XXXXXX_XXX.xlsx的测试报告文件名
                     for _root, _dirs, files in os.walk(os.path.join('report', task_dict['test_name'])):
-                        files_report = files[0]
-                    # 取出XXX-Report@XXXXXX_XXX.xml的测试汇总文件名
+                        if files:
+                            files_report = files[0]
+                            files_report_obj = read_data(os.path.join('report', task_dict['test_name'], files_report),
+                                                         '', 'rb')
+                    # 如果文件存在则取出XXX-Report@XXXXXX_XXX.xml的测试汇总文件名
                     for _root, _dirs, files in os.walk('JUnit'):
-                        files_junit = files[0]
-                    # 读取测试报告文件
-                    with open(os.path.join('report', task_dict['test_name'], files_report), 'rb') as fp1:
-                        files_report_obj = fp1.read()
-                    # 读取测试汇总文件
-                    with open(os.path.join('JUnit', files_junit), 'rb') as fp2:
-                        files_junit_obj = fp2.read()
+                        if files:
+                            files_junit = files[0]
+                            files_junit_obj = read_data(os.path.join('JUnit', files_junit), '', 'rb')
+
                     # 读取测试详情文件
-                    with open(os.path.join('details', 'details.txt'), 'rb') as fp3:
-                        files_details_obj = fp3.read()
+                    if os.path.isfile(os.path.join('details', 'details.txt')):
+                        files_details_obj = read_data(os.path.join('details', 'details.txt'), '', 'rb')
                     # 读取测试日志文件
-                    self.read_log_file()
-                    with open(os.path.join('log', 'new.log'), 'rb') as fp4:
-                        files_log_obj = fp4.read()
+                    if os.path.isfile(os.path.join('log', 'new.log')):
+                        files_log_obj = read_data(os.path.join('log', 'new.log'), '', 'rb')
                     # 汇总XXX-Report@XXXXXX_XXX.xlsx、XXX-Report@XXXXXX_XXX.xml、details.txt、new.log文件对象
                     files_obj = {
                         'file_obj': (str(task_dict['queue_id']) + '.xlsx', files_report_obj),
