@@ -28,13 +28,13 @@ class Autotest:
         g.init(self.desired_caps, self.server_url)
 
         plan_path = Path('snapshot') / g.plan_name
-        task_path = plan_path / g.start_time[1:] 
+        task_path = plan_path / g.start_time[1:]
 
         for p in ('JUnit', 'report', 'snapshot', plan_path, task_path, 'report/' + g.plan_name):
             mkdir(p)
-                  
+
         g.plan_data['log'] = set_log(logger, task_path)
-        
+
         self.testcase_file = str(
             Path('testcase') / (file_name + '-' + _testcase + '.xlsx'))
         self.elements_file = str(
@@ -107,7 +107,7 @@ class Autotest:
             data_file = Path('data') / (g.plan_name +
                                         '-' + sheet_name + '.csv')
             if data_file.is_file():
-                g.var = get_record(str(data_file))
+                g.test_data = get_record(str(data_file))
             w.init()
         except:
             logger.exception('*** Init global object failure ***')
@@ -124,9 +124,9 @@ class Autotest:
             sys.exit(self.code)
 
         # 4.执行测试套件
-        ts = TestSuite(testsuite, sheet_name,
-                       self.junit_suite[sheet_name], self.conditions)
-        ts.run()
+        g.ts = TestSuite(testsuite, sheet_name,
+                         self.junit_suite[sheet_name], self.conditions)
+        g.ts.run()
 
         # 5.判断测试结果
         if self.junit_suite[sheet_name].high_errors + self.junit_suite[sheet_name].medium_errors + \
@@ -141,6 +141,5 @@ class Autotest:
         except:
             logger.exception('*** Save the report is failure ***')
 
-
-    def md(self, md_path):
+    def report(self, md_path):
         markdown(self.plan_data, self.testsuite_data, self.report_data, md_path)
