@@ -11,9 +11,15 @@ class DB:
         try:
             if arg['type'].lower() == 'mongodb':
                 import pymongo
-                user = arg['user'] + ':' if arg.get('user') else ''
-                password = arg['password'] + '@' if arg.get('password') else ''
-                self.connect = pymongo.MongoClient('mongodb://' + user + password + arg['host'] + ':' + arg['port'] + '/')
+                host = arg.pop('host') if arg.get('host') else 'localhost:27017'
+                host = host.split(',') if ',' in host else host
+                port = int(arg.pop('port')) if arg.get('port') else 27017
+                if arg.get('user'):
+                    arg['username'] = arg.pop('user')
+                # username = arg['user'] if arg.get('user') else ''
+                # password = arg['password'] if arg.get('password') else ''
+                # self.connect = pymongo.MongoClient('mongodb://' + username + password + arg['host'] + ':' + arg['port'] + '/')
+                self.connect = pymongo.MongoClient(host=host, port=port, **arg)
                 self.connect.server_info()
                 self.db = self.connect[arg['dbname']]
 
@@ -22,7 +28,8 @@ class DB:
             if arg['type'].lower() == 'mysql':
                 import pymysql as mysql
                 self.connect = mysql.connect(
-                    host=arg['host'], port=int(arg['port']), user=arg['user'], password=arg['password'], database=arg['dbname'], charset=arg.get('charset', 'utf8'))
+                    host=arg['host'], port=int(arg['port']), user=arg['user'], password=arg['password'],
+                    database=arg['dbname'], charset=arg.get('charset', 'utf8'))
                 self.cursor = self.connect.cursor()
                 sql = 'select version()'
 
@@ -38,7 +45,8 @@ class DB:
             elif arg['type'].lower() == 'sqlserver':
                 import pymssql as sqlserver
                 self.connect = sqlserver.connect(
-                    host=arg['host'], port=arg['port'], user=arg['user'], password=arg['password'], database=arg['dbname'], charset=arg.get('charset', 'utf8'))
+                    host=arg['host'], port=arg['port'], user=arg['user'], password=arg['password'],
+                    database=arg['dbname'], charset=arg.get('charset', 'utf8'))
                 self.cursor = self.connect.cursor()
                 sql = 'select @@version'
 
@@ -77,7 +85,6 @@ class DB:
             logger.exception('*** Execute failure ***')
             raise
 
-
     def mongo(self, collection, sql):
         try:
             cmd = 'self.db[\'' + collection + '\'].' + sql
