@@ -12,7 +12,7 @@ from x_sweetest.utility import json2dict
 def execute(step):
     # 先处理循环结束条件
     condition = ''
-    for k in ('循环结束条件', 'condition'):
+    for k in ('循环结束条件', 'condition', '#break'):
         if step['data'].get(k):
             condition = step['data'].get(k)
             del step['data'][k]
@@ -46,7 +46,7 @@ def execute(step):
     # 初始化测试片段执行结果
     result = 'success'
     steps = []
-    if element != '变量赋值':
+    if step['page'] in ('用例片段', 'SNIPPET'):
         g.var['_last_'] = False
         for t in range(times):
             if t > 0:
@@ -59,7 +59,7 @@ def execute(step):
             tc.run()
             for s in testcase['steps']:
                 s['no'] = str(step['no']) + '*' + \
-                    str(t + 1) + '-' + str(s['no'])
+                          str(t + 1) + '-' + str(s['no'])
             steps += testcase['steps']
             # 用例片段执行失败时
             if testcase['result'] != 'success':
@@ -76,13 +76,28 @@ def execute(step):
                 # 如果循环退出条件是成功，则直接返回，返回结果是 success
                 if condition == 'success':
                     return 'success', testcase['steps']
-            
+
             if g.var['_last_']:
                 g.var['_last_'] = False
                 break
         # 执行结束，还没有触发循环退出条件，则返回结果为 failure
         if condition:
             return 'failure', testcase['steps']
+    elif step['page'] in ('用例组合', 'CASESET'):
+        caseset = element
+        for t in range(times):
+            if t > 0:
+                _data = data_format(str(step['_data']))
+                replace_dict(_data)
+                for k, v in _data.items():
+                    g.var[k] = v
+            for testcase in g.caseset[caseset]:
+                testcase = deepcopy(testcase)
+                testcase['flag'] = ''
+                g.ts.run_testcase(testcase)
+                g.casesets.append(testcase)
+                # if testcase['result'] != 'success':
+                #     result = testcase['result']
     return result, steps
 
 
@@ -94,18 +109,17 @@ def dedup(text):
     n = 0
 
     for s in text:
-        if s not in ( '(', ')'):
+        if s not in ('(', ')'):
             if n <= 0:
                 _text += s
         elif s == '(':
             n += 1
         elif s == ')':
             n -= 1
-    return _text    
+    return _text
 
 
 def sql(step):
-
     response = {}
 
     element = step['element']
@@ -150,7 +164,8 @@ def sql(step):
         result = check(expected.pop('json'), response['json'])
         logger.info('json check result: %s' % result)
         if result['code'] != 0:
-            raise Exception(f'json | EXPECTED:{repr(expected["json"])}, REAL:{repr(response["json"])}, RESULT: {result}')
+            raise Exception(
+                f'json | EXPECTED:{repr(expected["json"])}, REAL:{repr(response["json"])}, RESULT: {result}')
         elif result['var']:
             var = dict(var, **result['var'])
             g.var = dict(g.var, **result['var'])
