@@ -80,7 +80,7 @@ def request(kw, step):
             data.pop('params', '{}')) or json2dict(data.pop('data', '{}'))
     elif kw == 'post':
         if data.get('text'):
-            _data['data'] = data.pop('text')
+            _data['data'] = data.pop('text').encode('utf-8')
         else:
             _data['data'] = json2dict(data.pop('data', '{}'))
         _data['json'] = json2dict(data.pop('json', '{}'))
@@ -157,16 +157,20 @@ def request(kw, step):
             # 将 'form' json数据转为字典数据
             form_dict = json2dict(data['form'])
             try:
-                if len(form_dict) == 1:
-                    for form_k, form_v in form_dict.items():
-                        # 取出待上传的文件名称
-                        form_name = form_k.split("/")[-1]
-                        # 使用 MultipartEncoder 模块对上传的文件进行解析
-                        form_data = MultipartEncoder(fields={'file': (form_name, open(form_k, 'rb'), form_v)})
-                        # 在请求头里添加上传文件类型
-                        form_headers = {'Content-Type': form_data.content_type}
-                        http.r.headers.update(form_headers)
-                        r = getattr(http.r, kw)(http.baseurl + url, data=form_data, timeout=timeout)
+                fields_dict = {}
+                for form_k, form_v in form_dict.items():
+                    if form_k != 'file':
+                        fields_dict[form_k] = form_v
+                # 取出待上传的文件名称
+                form_name = form_dict['file'][0].split("/")[-1]
+                # fields_dict 是 MultipartEncoder 中 fields 字段需要的字典
+                fields_dict.update({'file': (form_name, open(form_dict['file'][0], 'rb'), form_dict['file'][1])})
+                # 使用 MultipartEncoder 模块对上传的文件进行解析
+                form_data = MultipartEncoder(fields=fields_dict)
+                # 在请求头里添加上传文件类型
+                form_headers = {'Content-Type': form_data.content_type}
+                http.r.headers.update(form_headers)
+                r = getattr(http.r, kw)(http.baseurl + url, data=form_data, timeout=timeout)
             except:
                 logger.exception("***form can be only one Key-value***")
         else:
@@ -226,25 +230,30 @@ def request(kw, step):
 
     var = {}  # 存储所有输出变量
 
+    # 测试报告 “备注” 列显示URL请求地址
+    REQUEST_URL = f'URL: {http.baseurl + url}\n'
+
     if expected['status_code']:
-        if str(expected['status_code']) != str(response['status_code']):
+        # 对比 实际响应状态码 与 预期响应状态码
+        if str(expected['status_code']).strip() != str(response['status_code']).strip():
+            # 抛异常行加：{REQUEST_URL}
             raise Exception(
-                f'status_code | EXPECTED:{repr(expected["status_code"])}, REAL:{repr(response["status_code"])}')
+                f'{REQUEST_URL}status_code | EXPECTED:{repr(expected["status_code"])}, REAL:{repr(response["status_code"])}')
 
     if expected['text']:
         if expected['text'].startswith('*'):
             if expected['text'][1:] not in response['text']:
-                raise Exception(f'text | EXPECTED:{repr(expected["text"])}, REAL:{repr(response["text"])}')
+                raise Exception(f'{REQUEST_URL}text | EXPECTED:{repr(expected["text"])}, REAL:{repr(response["text"])}')
         else:
             if expected['text'] == response['text']:
-                raise Exception(f'text | EXPECTED:{repr(expected["text"])}, REAL:{repr(response["text"])}')
+                raise Exception(f'{REQUEST_URL}text | EXPECTED:{repr(expected["text"])}, REAL:{repr(response["text"])}')
 
     if expected['headers']:
         result = check(expected['headers'], response['headers'])
         logger.info('headers check result: %s' % result)
         if result['code'] != 0:
             raise Exception(
-                f'headers | EXPECTED:{repr(expected["headers"])}, REAL:{repr(response["headers"])}, RESULT: {result}')
+                f'{REQUEST_URL}headers | EXPECTED:{repr(expected["headers"])}, REAL:{repr(response["headers"])}, RESULT: {result}')
         elif result['var']:
             var = dict(var, **result['var'])
             g.var = dict(g.var, **result['var'])
@@ -256,7 +265,7 @@ def request(kw, step):
         logger.info('cookies check result: %s' % result)
         if result['code'] != 0:
             raise Exception(
-                f'cookies | EXPECTED:{repr(expected["cookies"])}, REAL:{repr(response["cookies"])}, RESULT: {result}')
+                f'{REQUEST_URL}cookies | EXPECTED:{repr(expected["cookies"])}, REAL:{repr(response["cookies"])}, RESULT: {result}')
         elif result['var']:
             var = dict(var, **result['var'])
             g.var = dict(g.var, **result['var'])
@@ -272,7 +281,7 @@ def request(kw, step):
         logger.info('json check result: %s' % result)
         if result['code'] != 0:
             raise Exception(
-                f'json | EXPECTED:{repr(expected["json"])}, REAL:{repr(response["json"])}, RESULT: {result}')
+                f'{REQUEST_URL}json | EXPECTED:{repr(expected["json"])}, REAL:{repr(response["json"])}, RESULT: {result}')
         elif result['var']:
             var = dict(var, **result['var'])
             g.var = dict(g.var, **result['var'])
@@ -280,7 +289,7 @@ def request(kw, step):
 
     if expected['time']:
         if expected['time'] < r.elapsed.total_seconds():
-            raise Exception(f'time | EXPECTED:{repr(expected["time"])}, REAL:{repr(r.elapsed.total_seconds())}')
+            raise Exception(f'{REQUEST_URL}time | EXPECTED:{repr(expected["time"])}, REAL:{repr(r.elapsed.total_seconds())}')
 
     output = step['output']
     # if output:
