@@ -11,7 +11,6 @@ import random
 from x_sweetest.config import header
 from x_sweetest.globals import g
 
-
 path = Path('lib/http_handle.py')
 if path.exists():
     from lib import *
@@ -201,7 +200,7 @@ def replace_old(data):
         # 正则匹配出 k 中的 + - ** * // / % , ( ) 返回列表
         values = re.split(r'(\+|-|\*\*|\*|//|/|%|,|\(|\)|\'|\")', k)
         for j, v in enumerate(values):
-            #切片操作处理，正则匹配出 [] 中内容
+            # 切片操作处理，正则匹配出 [] 中内容
             s = v.split('[', 1)
             index = ''
             if len(s) == 2:
@@ -257,16 +256,19 @@ def replace_old(data):
 def replace(data):
     if data.startswith("'''") and data.endswith("'''"):
         return data[3:-3]
+
     left_angle = 'dsfw4rwfdfstg43'
     right_angle = '3dsdtgsgt43trfdf'
     left_delimiter = '<'
     right_delimiter = '>'
     data = data.replace(r'\<', left_angle).replace(r'\>', right_angle)
+
     if '<<' in data and '>>' in data:
         left_delimiter = '<<'
         right_delimiter = '>>'
-        # 正则匹配出 data 中所有 <> 中的变量，返回列表
-    keys = re.findall(r'%s' %(left_delimiter+'(.*?)'+right_delimiter), data)
+
+    # 正则匹配出 data 中所有 <> 中的变量，返回列表
+    keys = re.findall(r'%s' % (left_delimiter + '(.*?)' + right_delimiter), data)
     _vars = {}
 
     for k in keys:
@@ -274,39 +276,41 @@ def replace(data):
         # 正则匹配出 k 中的 + - ** * // / % , ( ) 返回列表
         values = re.split(r'(\+|-|\*\*|\*|//|/|%|,|\(|\))', k)
         for v in values:
-            #切片操作处理，正则匹配出 [] 中内容
+            # 切片操作处理，正则匹配出 [] 中内容
             s = v.split('[', 1)
             index = ''
             if len(s) == 2:
                 v = s[0]
                 index = '[' + s[1]
 
-            if v in g.var and v not in _vars:
-                # 如果在 var 中是 list
-                if v.startswith('_') and isinstance(g.var[v], list) and not index:
-                    # 是测试数据文件中的值，则 pop 第一个值
-                    if len(g.var[v]) == 0:
-                        raise Exception('The key:%s is no value in data csv' %v)
-                    elif len(g.var[v]) == 1:
-                        _vars[v] = g.var[v][0]
-                        g.var['_last_'] = True
-                    else:
-                        _vars[v] = g.var[v].pop(0)
-
-                else:
+            if v not in _vars:
+                if v in g.var:
+                    # 如果在 g.var 中是值，则直接赋值
                     _vars[v] = g.var[v]
+                elif v in g.test_data:
+                    # 是测试数据文件中的值
+                    if len(g.test_data[v]) == 0:  # 为空 list 报错
+                        raise Exception('The key:%s is no value in data csv' % v)
+                    elif len(g.test_data[v]) == 1:  # 最后一个 list 元素，赋值
+                        _vars[v] = g.test_data[v][0]
+                        g.var['_last_'] = True  # 处理循环次数为 N 的情况，此标志标明循环到最后一个变量
+                    else:  # 大于 1 个元素，pop 赋值
+                        _vars[v] = g.test_data[v].pop(0)
 
         try:
             value = eval(k, globals(), _vars)
         except NameError:
-            value = left_delimiter+ k + right_delimiter
-        
-        if data == left_delimiter+ keys[0] + right_delimiter:
+            value = left_delimiter + k + right_delimiter
+
+        if data == left_delimiter + keys[0] + right_delimiter:
             data = value
         # 否则需要替换，此时变量强制转换为为字符串
         else:
             data = data.replace(left_delimiter + k + right_delimiter, str(value))
-            data = data.replace(left_angle, '<').replace(right_angle, '>')
+
+    if isinstance(data, str):
+        data = data.replace(left_angle, '<').replace(right_angle, '>')
+
     return data
 
 
@@ -342,16 +346,16 @@ def get_record(data_file):
         data = read_csv(data_file)
 
     def read_data():
-        num = len(data[0])-1 if flag else len(data[0])
+        num = len(data[0]) - 1 if flag else len(data[0])
         for i in range(num):
             if d[i]:
                 k = data[0][i]
                 if record.get(k, None):
-                    if isinstance(record[k], str):
-                        record[k] = [record[k]]
+                    # if isinstance(record[k], str):
+                    #    record[k] = [record[k]]
                     record[k].append(d[i])
                 else:
-                    record[k] = d[i]
+                    record[k] = [d[i]]
                 if record[k][-1] == '&quot;':  # 空字符转换
                     record[k][-1] = ''
 
@@ -364,7 +368,7 @@ def get_record(data_file):
         if not flag:
             read_data()
         elif d[-1] == 'N':
-            read_data()    
+            read_data()
         elif d[-1] != 'Y':
             read_data()
             d[-1] = 'Y'
@@ -406,13 +410,13 @@ def str2float(s, n=None):
 
 def f(v, e, n=2):
     '''
-    判断2个 float 数值是否相同，类型可以是 str 或 float 
-    v: 实际值，如：12.345, '1234.56', '1,234.5600' 
+    判断2个 float 数值是否相同，类型可以是 str 或 float
+    v: 实际值，如：12.345, '1234.56', '1,234.5600'
     e: 预期结果, 示例值同 v
     n: 小数点精确位数
     '''
     v = str(v).replace(',', '')
-    e = str(e).replace(',', '') 
+    e = str(e).replace(',', '')
     _v = round(float(v), n)
     _e = round(float(e), n)
     assert round(_v, n) == round(_e, n)
@@ -448,9 +452,9 @@ def compare(data, real):
             assert data[1:] != str(real)
             return
         elif data.startswith(':'):
-            exec('v=real;'+data[1:])
+            exec('v=real;' + data[1:])
             return
-                    
+
         assert isinstance(real, str)
 
         if data.startswith('*'):
